// src/index.ts
import { createUnplugin } from "unplugin";
import { createFilter } from "@rollup/pluginutils";

// src/core/options.ts
function resolveOption(options) {
  return {
    include: options.include || [/\.(vue|[cm]?[jt]sx?)$/],
    exclude: options.exclude || [/node_modules/],
    enforce: "enforce" in options ? options.enforce : "pre"
  };
}

// src/core/transform/index.ts
import {
  MagicString,
  babelParse,
  getLang,
  getTransformResult,
  parseSFC
} from "@vue-macros/common";

// src/core/transform/v-if.ts
import { walkAST } from "@vue-macros/common";
function vIfTransform({
  s,
  parseResult
}) {
  const nodeMap = /* @__PURE__ */ new Map();
  walkAST(parseResult, {
    enter(node, parent) {
      if (node.type !== "JSXElement")
        return;
      const attribute = node.openingElement.attributes.find(
        (i) => i.type === "JSXAttribute" && ["v-if", "v-else-if", "v-else"].includes(`${i.name.name}`)
      );
      if (attribute) {
        if (!nodeMap.has(parent))
          nodeMap.set(parent, []);
        nodeMap.get(parent)?.push({
          node,
          attribute
        });
      }
    }
  });
  const nodes = [...nodeMap.values()].flat();
  nodes.forEach(({ node, attribute }, index) => {
    if (["v-if", "v-else-if"].includes(`${attribute.name.name}`)) {
      if (attribute.value)
        s.appendLeft(
          node.start,
          `${attribute.name.name === "v-if" ? "{ " : ""}${s.slice(
            attribute.value.start + 1,
            attribute.value.end - 1
          )} ? `
        );
      s.appendRight(
        node.end,
        `${nodes[index + 1]?.attribute.name.name}`.startsWith("v-else") ? " :" : " : ''}"
      );
      s.removeNode(attribute);
    } else {
      s.appendRight(node.end, " }");
    }
  });
  return s;
}

// src/core/transform/v-for.ts
import { walkAST as walkAST2 } from "@vue-macros/common";
function vForTransform({
  s,
  parseResult
}) {
  const nodes = [];
  walkAST2(parseResult, {
    enter(node) {
      if (node.type !== "JSXElement")
        return;
      const attribute = node.openingElement.attributes.find(
        (i) => i.type === "JSXAttribute" && ["v-for"].includes(`${i.name.name}`)
      );
      if (attribute) {
        nodes.push({
          node,
          attribute
        });
      }
    }
  });
  nodes.forEach(({ node, attribute }) => {
    if (`${attribute.name.name}` === "v-for") {
      if (!attribute.value)
        return;
      const [i, , list] = s.slice(attribute.value.start + 1, attribute.value.end - 1).split(/\s/);
      s.appendLeft(node.start, ` { ${list}.map(${i}=>`);
      s.appendRight(node.end, ") }");
      s.removeNode(attribute);
    }
  });
  return s;
}

// src/core/transform/index.ts
function transform(code, id) {
  const lang = getLang(id);
  let content = code;
  if (lang === "vue") {
    const { scriptSetup, script } = parseSFC(code, id);
    content = `${scriptSetup?.content}${script?.content}`;
  }
  if (!/v-for|v-if/.test(content))
    return null;
  const parseResult = babelParse(code, lang === "vue" ? "js" : lang);
  const s = new MagicString(code);
  if (content.includes("v-if"))
    vIfTransform({ s, parseResult });
  if (content.includes("v-for"))
    vForTransform({ s, parseResult });
  return getTransformResult(s, id);
}

// src/index.ts
var src_default = createUnplugin((rawOptions = {}) => {
  const options = resolveOption(rawOptions);
  const filter = createFilter(options.include, options.exclude);
  const name = "unplugin-jsx-vue-directive";
  return {
    name,
    enforce: options.enforce,
    transformInclude(id) {
      return filter(id);
    },
    transform
  };
});

export {
  src_default
};
